# This package depends on automagic byte compilation
# https://fedoraproject.org/wiki/Changes/No_more_automagic_Python_bytecompilation_phase_2
%global _python_bytecompile_extra 1

Name:           fish
Version:        3.0.2
Release:        1%{?dist}
Summary:        Friendly interactive shell

# GPLv2
#   - src/fish.cpp
#   and rest..
# GPLv2+
#   - src/builtin_printf.cpp
# BSD
#   - share/tools/create_manpage_completions.py
# ISC
#   - src/utf8.cpp
#   - src/utf8.h
# LGPLv2+
#   - src/wgetopt.c
#   - src/wgetopt.h
# MIT
#   - share/completions/grunt.fish
#   - share/tools/web_config/js/angular-sanitize.js
#   - share/tools/web_config/js/angular.js
License:        GPLv2 and BSD and ISC and LGPLv2+ and MIT
URL:            https://fishshell.com
Source0:        https://github.com/fish-shell/fish-shell/releases/download/%{version}/%{name}-%{version}.tar.gz
# https://github.com/fish-shell/fish-shell/commit/742fde0dd68858ad603b449501f0c42cd7864fab
Patch0001:      0001-Don-t-use-less-in-highlighting-test.patch

BuildRequires:  cmake >= 3.2
BuildRequires:  ninja-build
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  doxygen
BuildRequires:  ncurses-devel
BuildRequires:  pcre2-devel
BuildRequires:  python3-devel
%global __python %{__python3}

# tab completion wants man-db
Recommends:     man-db
Recommends:     man-pages
Recommends:     groff-base

Provides:       bundled(js-angular) = 1.0.8

%description
fish is a fully-equipped command line shell (like bash or zsh) that is
smart and user-friendly. fish supports powerful features like syntax
highlighting, autosuggestions, and tab completions that just work, with
nothing to learn or configure.

%prep
%autosetup -p1
rm -vrf pcre2-*

# Change the bundled scripts to invoke the python binary directly.
for f in $(find share/tools -type f -name '*.py'); do
    sed -i -e '1{s@^#!.*@#!%{__python3}@}' "$f"
done

%build
%cmake . -B%{_vpath_builddir} -GNinja -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir}
%ninja_build -C %{_vpath_builddir} all fish_tests

%install
%ninja_install -C %{_vpath_builddir}

# Install docs from tarball root
cp -a README.md %{buildroot}%{_pkgdocdir}
cp -a CONTRIBUTING.md %{buildroot}%{_pkgdocdir}

# filesystem will own a couple of config directories so that other packages
# can ship fish config snippets without requiring fish:
rmdir %{buildroot}%{_datadir}/fish/vendor_completions.d
rmdir %{buildroot}%{_datadir}/fish/vendor_conf.d

%find_lang %{name}

%check
%{_vpath_builddir}/fish_tests

%post
if [ "$1" = 1 ]; then
  if [ ! -f %{_sysconfdir}/shells ] ; then
    echo "%{_bindir}/fish" > %{_sysconfdir}/shells
    echo "/bin/fish" >> %{_sysconfdir}/shells
  else
    grep -q "^%{_bindir}/fish$" %{_sysconfdir}/shells || echo "%{_bindir}/fish" >> %{_sysconfdir}/shells
    grep -q "^/bin/fish$" %{_sysconfdir}/shells || echo "/bin/fish" >> %{_sysconfdir}/shells
  fi
fi

%postun
if [ "$1" = 0 ] && [ -f %{_sysconfdir}/shells ] ; then
  sed -i '\!^%{_bindir}/fish$!d' %{_sysconfdir}/shells
  sed -i '\!^/bin/fish$!d' %{_sysconfdir}/shells
fi

%files -f %{name}.lang
%license COPYING
%{_mandir}/man1/fish*.1*
%{_bindir}/fish*
%config(noreplace) %{_sysconfdir}/fish/
%{_datadir}/fish/
%{_datadir}/pkgconfig/fish.pc
%{_pkgdocdir}

%changelog
* Tue Feb 19 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.0.2-1
- Update to 3.0.2

* Sat Feb 16 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.0.1-1
- Update to 3.0.1

* Wed Jan 16 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 3.0.0-1
- Initial package
